%may
% Function which illustrates May's bifircations in the logistic equation
% x(n+1) = rx(n)*( 1 - x(n) )
%
% LAST UPDATED by Andy French August 2017

function may

%Growth parameter
r = 3.5;

%Number of iterations
N=50;

%Number of x starting values between 0 and 1
M = 100;

%Fontsize
fsize = 18;

%

%Create vector of initial values of x
xx = linspace(0.01,0.99,M);
x = xx;

%Create a vector of iteration numbers
iter = 0 : 1 : N;
iter = repmat( iter.', [1,M] );

%Use May's iterative formula to compute subsequent x values
for n=1:N
    xx = r*xx.*(1-xx);
    x = [x;xx];
end

%Plot iterations
figure('name','May bifurcations','color',[1 1 1])
plot( iter, x,'.' );
ylim([0,1])
xlabel('Iteration','fontsize',fsize)
ylabel('x','fontsize',fsize)
set(gca,'fontsize',fsize)
title(['r = ',num2str(r)],'fontsize',fsize)
grid on
print( gcf, ['may r=',num2str(r),'.png'],'-r300','-dpng' );

%End of code

    